@@ -1,4 +1,4 @@
-from datetime import datetime, UTC
+from datetime import datetime
 import logging
 from functools import wraps
 from typing import Any, Callable, TypeVar
@@ -13,7 +13,12 @@ from testit_python_commons.services import (
 Func = TypeVar("Func", bound=Callable[..., Any])
 
 
+# if we return title: "", it will be replaced to
+# step name in fact later
 def step(*args, **kwargs):
+    if len(args) == 0:
+        return StepContext("", None, {})
+
     if callable(args[0]):
         function = args[0]
         return StepContext(function.__name__, None, {})(function)
@@ -52,7 +57,7 @@ class StepContext:
         self.__parameters = parameters
 
     def __enter__(self):
-        self.__start_time = round(datetime.now(UTC).timestamp() * 1000)
+        self.__start_time = round(datetime.utcnow().timestamp() * 1000)
         self.__step_result = StepResult()
 
         self.__title = Utils.collect_parameters_in_string_attribute(self.__title, self.__parameters)
@@ -74,7 +79,7 @@ class StepContext:
             else TmsPluginManager.get_plugin_manager().hook.get_pytest_check_outcome()[0] if \
             hasattr(TmsPluginManager.get_plugin_manager().hook, 'get_pytest_check_outcome') \
             else 'Passed'
-        duration = round(datetime.now(UTC).timestamp() * 1000) - self.__start_time
+        duration = round(datetime.utcnow().timestamp() * 1000) - self.__start_time
 
         self.__step_result\
             .set_outcome(outcome)\
